@@ -45,7 +45,6 @@ class QKeyEvent;
 */
 class ApplyProgressDialog : public QDialog
 {
-    Q_OBJECT
     Q_DISABLE_COPY(ApplyProgressDialog)
 
 public:
@@ -64,7 +63,7 @@ public:
         return *m_Report;
     }
 
-protected Q_SLOTS:
+protected:
     void onAllOpsFinished();
     void onAllOpsCancelled();
     void onAllOpsError();
@@ -73,17 +72,18 @@ protected Q_SLOTS:
     void onOkButton();
     void onOpStarted(int num, Operation* op);
     void onOpFinished(int num, Operation* op);
-    void onJobStarted(Job* job, Operation* op);
-    void onJobFinished(Job* job, Operation* op);
     void onSecondElapsed();
     void saveReport();
-    void toggleDetails();
     void browserReport();
+    void updateReportUnforced();
     void updateReport(bool force = false);
 
-protected:
-    void closeEvent(QCloseEvent* e);
-    void keyPressEvent(QKeyEvent* e);
+    void onJobStarted(Job* job, Operation* op);
+    void onJobFinished(Job* job, Operation* op);
+    void toggleDetails();
+
+    void closeEvent(QCloseEvent* e) override;
+    void keyPressEvent(QKeyEvent* e) override;
 
     void setupConnections();
 
