@@ -22,12 +22,12 @@
 
 #include <core/partition.h>
 
-#include <KMessageBox>
-#include <KGuiItem>
-#include <KStandardGuiItem>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KGuiItem>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KSharedConfig>
+#include <KStandardGuiItem>
 
 #include <QDialogButtonBox>
 
@@ -66,8 +66,8 @@ void EditMountPointDialog::accept()
     if (KMessageBox::warningContinueCancel(this,
                                            xi18nc("@info", "<para>Are you sure you want to save the changes you made to the system table file <filename>/etc/fstab</filename>?</para>"
                                                    "<para><warning>This will overwrite the existing file on your hard drive now. This <strong>can not be undone</strong>.</warning></para>"),
-                                           i18nc("@title:window", "Really save changes?"),
-                                           KGuiItem(i18nc("@action:button", "Save changes"), QStringLiteral("arrow-right")),
+                                           xi18nc("@title:window", "Really save changes?"),
+                                           KGuiItem(xi18nc("@action:button", "Save changes"), QStringLiteral("arrow-right")),
                                            KStandardGuiItem::cancel(),
                                            QStringLiteral("reallyWriteMountPoints")) == KMessageBox::Cancel)
         return;
