@@ -26,15 +26,14 @@
 #include <fs/luks.h>
 
 #include <KLocalizedString>
-#include <KIOCore/KMountPoint>
 #include <KMessageBox>
+#include <KMountPoint>
 
-#include <QString>
-#include <QWidget>
+#include <QDebug>
 #include <QFile>
 #include <QFileDialog>
 #include <QPointer>
-#include <QDebug>
+#include <QString>
 
 #include <mntent.h>
 #include <blkid/blkid.h>
@@ -67,7 +66,7 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
     m_deviceNode = partition().deviceNode();
     if (partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Luks) {
         const FS::luks* luksFs = dynamic_cast<const FS::luks*>(&partition().fileSystem());
-        m_deviceNode = luksFs->mapperName(m_deviceNode);
+        m_deviceNode = luksFs->mapperName();
     }
     labelName().setText(m_deviceNode);
     labelType().setText(partition().fileSystem().name());
@@ -135,11 +134,12 @@ void EditMountPointDialogWidget::setupOptions(const QStringList& options)
 {
     QStringList optTmpList;
 
-    foreach(const QString & o, options)
-    if (boxOptions().find(o) != boxOptions().end())
-        boxOptions()[o]->setChecked(true);
-    else
-        optTmpList.append(o);
+    for (const auto &o : options) {
+        if (boxOptions().find(o) != boxOptions().end())
+            boxOptions()[o]->setChecked(true);
+        else
+            optTmpList.append(o);
+    }
 
     m_Options = optTmpList.join(QStringLiteral(","));
 }
@@ -161,13 +161,14 @@ void EditMountPointDialogWidget::buttonMoreClicked(bool)
     delete dlg;
 }
 
-QStringList EditMountPointDialogWidget::options()
+QStringList EditMountPointDialogWidget::options() const
 {
     QStringList optList = m_Options.split(QStringLiteral(","), QString::SkipEmptyParts);
 
-    foreach(const QString & s, boxOptions().keys())
-    if (boxOptions()[s]->isChecked())
-        optList.append(s);
+    const auto keys = boxOptions().keys();
+    for (const auto &s : keys)
+        if (boxOptions()[s]->isChecked())
+            optList.append(s);
 
     return optList;
 }
@@ -179,7 +180,7 @@ bool EditMountPointDialogWidget::readMountpoints(const QString& filename)
     if (fp == nullptr) {
         KMessageBox::sorry(this,
                            xi18nc("@info", "Could not open mount point file <filename>%1</filename>.", filename),
-                           i18nc("@title:window", "Error while reading mount points"));
+                           xi18nc("@title:window", "Error while reading mount points"));
         return false;
     }
 
@@ -265,8 +266,9 @@ bool EditMountPointDialogWidget::writeMountpoints(const QString& filename)
         qWarning() << "could not open output file " << newFilename;
         rval = false;
     } else {
-        foreach(const MountEntry * me, mountPoints())
-        writeEntry(out, me);
+        const auto mp = mountPoints();
+        for (const auto &me : mp)
+            writeEntry(out, me);
 
         out.close();
 
@@ -287,7 +289,7 @@ bool EditMountPointDialogWidget::writeMountpoints(const QString& filename)
     if (!rval)
         KMessageBox::sorry(this,
                            xi18nc("@info", "Could not save mount points to file <filename>%1</filename>.", filename),
-                           i18nc("@title:window", "Error While Saving Mount Points"));
+                           xi18nc("@title:window", "Error While Saving Mount Points"));
 
     return rval;
 }
