@@ -19,14 +19,17 @@
 #include "gui/infopane.h"
 
 #include <core/device.h>
+#include <core/diskdevice.h>
+#include <core/lvmdevice.h>
 #include <core/partition.h>
 
 #include <fs/filesystem.h>
 #include <fs/luks.h>
+#include <fs/lvm2_pv.h>
 
 #include <util/capacity.h>
+#include <util/helpers.h>
 
-#include <QDockWidget>
 #include <QFontDatabase>
 #include <QFrame>
 #include <QGridLayout>
@@ -48,7 +51,7 @@ InfoPane::InfoPane(QWidget* parent) :
 /** Clears the InfoPane, leaving it empty */
 void InfoPane::clear()
 {
-    parentWidget()->parentWidget()->setWindowTitle(i18nc("@title:window", "Information"));
+    parentWidget()->parentWidget()->setWindowTitle(xi18nc("@title:window", "Information"));
     qDeleteAll(findChildren<QLabel*>());
     qDeleteAll(findChildren<QFrame*>());
 }
@@ -107,31 +110,46 @@ void InfoPane::createLabels(const QString& title, const QString& value, const in
 void InfoPane::showPartition(Qt::DockWidgetArea area, const Partition& p)
 {
     clear();
-    parentWidget()->parentWidget()->setWindowTitle(i18nc("@title:window", "Partition Information"));
+    parentWidget()->parentWidget()->setWindowTitle(xi18nc("@title:window", "Partition Information"));
 
     int x = 0;
     int y = createHeader(p.deviceNode(), cols(area));
-    if (p.fileSystem().type() == FileSystem::Luks) {
-        const FS::luks* luksFs = dynamic_cast<const FS::luks*>(&p.fileSystem());
+    if (p.fileSystem().type() == FileSystem::Luks) { // inactive LUKS partition
+        const FS::luks* luksFs = static_cast<const FS::luks*>(&p.fileSystem());
         QString deviceNode = p.partitionPath();
         createLabels(i18nc("@label partition", "File system:"), p.fileSystem().name(), cols(area), x, y);
         createLabels(i18nc("@label partition", "Capacity:"), Capacity::formatByteSize(p.capacity()), cols(area), x, y);
-        createLabels(i18nc("@label partition", "Cipher name:"), luksFs->getCipherName(deviceNode), cols(area), x, y);
-        createLabels(i18nc("@label partition", "Cipher mode:"), luksFs->getCipherMode(deviceNode), cols(area), x, y);
-        createLabels(i18nc("@label partition", "Hash:"), luksFs->getHashName(deviceNode), cols(area), x, y);
-        createLabels(i18nc("@label partition", "Key size:"), QString::number(luksFs->getKeySize(deviceNode)), cols(area), x, y);
-        createLabels(i18nc("@label partition", "Payload offset:"), QString::number(luksFs->getPayloadOffset(deviceNode)), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Cipher name:"), luksFs->cipherName(), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Cipher mode:"), luksFs->cipherMode(), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Hash:"), luksFs->hashName(), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Key size:"), QString::number(luksFs->keySize()), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Payload offset:"), Capacity::formatByteSize(luksFs->payloadOffset()), cols(area), x, y);
         createLabels(i18nc("@label partition", "First sector:"), QLocale().toString(p.firstSector()), cols(area), x, y);
         createLabels(i18nc("@label partition", "Last sector:"), QLocale().toString(p.lastSector()), cols(area), x, y);
         createLabels(i18nc("@label partition", "Number of sectors:"), QLocale().toString(p.length()), cols(area), x, y);
-    } else {
+    } else if (p.fileSystem().type() == FileSystem::Lvm2_PV) {
+        FS::lvm2_pv *lvm2PVFs;
+        innerFS(&p, lvm2PVFs);
+        QString deviceNode = p.partitionPath();
         createLabels(i18nc("@label partition", "File system:"), p.fileSystem().name(), cols(area), x, y);
         createLabels(i18nc("@label partition", "Capacity:"), Capacity::formatByteSize(p.capacity()), cols(area), x, y);
         createLabels(i18nc("@label partition", "Available:"), Capacity::formatByteSize(p.available()), cols(area), x, y);
         createLabels(i18nc("@label partition", "Used:"), Capacity::formatByteSize(p.used()), cols(area), x, y);
+        createLabels(i18nc("@label partition", "PE Size:"), Capacity::formatByteSize(lvm2PVFs->peSize()), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Total PE:"), QString::number(lvm2PVFs->totalPE()), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Free PE:"), QString::number(lvm2PVFs->freePE()), cols(area), x, y);
+        createLabels(i18nc("@label partition", "Allocated PE:"), QString::number(lvm2PVFs->allocatedPE()), cols(area), x, y);
         createLabels(i18nc("@label partition", "First sector:"), QLocale().toString(p.firstSector()), cols(area), x, y);
         createLabels(i18nc("@label partition", "Last sector:"), QLocale().toString(p.lastSector()), cols(area), x, y);
         createLabels(i18nc("@label partition", "Number of sectors:"), QLocale().toString(p.length()), cols(area), x, y);
+    } else {
+        createLabels(xi18nc("@label partition", "File system:"), p.fileSystem().name(), cols(area), x, y);
+        createLabels(xi18nc("@label partition", "Capacity:"), Capacity::formatByteSize(p.capacity()), cols(area), x, y);
+        createLabels(xi18nc("@label partition", "Available:"), Capacity::formatByteSize(p.available()), cols(area), x, y);
+        createLabels(xi18nc("@label partition", "Used:"), Capacity::formatByteSize(p.used()), cols(area), x, y);
+        createLabels(xi18nc("@label partition", "First sector:"), QLocale().toString(p.firstSector()), cols(area), x, y);
+        createLabels(xi18nc("@label partition", "Last sector:"), QLocale().toString(p.lastSector()), cols(area), x, y);
+        createLabels(xi18nc("@label partition", "Number of sectors:"), QLocale().toString(p.length()), cols(area), x, y);
     }
 }
 
@@ -142,32 +160,44 @@ void InfoPane::showPartition(Qt::DockWidgetArea area, const Partition& p)
 void InfoPane::showDevice(Qt::DockWidgetArea area, const Device& d)
 {
     clear();
-    parentWidget()->parentWidget()->setWindowTitle(i18nc("@title:window", "Device Information"));
+    parentWidget()->parentWidget()->setWindowTitle(xi18nc("@title:window", "Device Information"));
 
     int x = 0;
     int y = createHeader(d.name(), cols(area));
-    createLabels(i18nc("@label device", "Path:"), d.deviceNode(), cols(area), x, y);
+    createLabels(xi18nc("@label device", "Path:"), d.deviceNode(), cols(area), x, y);
 
     QString type = QStringLiteral("---");
     QString maxPrimaries = QStringLiteral("---");
 
     if (d.partitionTable() != nullptr) {
         type = (d.partitionTable()->isReadOnly())
-               ? i18nc("@label device", "%1 (read only)", d.partitionTable()->typeName())
+               ? xi18nc("@label device", "%1 (read only)", d.partitionTable()->typeName())
                : d.partitionTable()->typeName();
         maxPrimaries = QStringLiteral("%1/%2").arg(d.partitionTable()->numPrimaries()).arg(d.partitionTable()->maxPrimaries());
     }
 
-    createLabels(i18nc("@label device", "Type:"), type, cols(area), x, y);
-    createLabels(i18nc("@label device", "Capacity:"), Capacity::formatByteSize(d.capacity()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Total sectors:"), QLocale().toString(d.totalSectors()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Heads:"), QString::number(d.heads()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Cylinders:"), QLocale().toString(d.cylinders()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Sectors:"), QLocale().toString(d.sectorsPerTrack()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Logical sector size:"), Capacity::formatByteSize(d.logicalSectorSize()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Physical sector size:"), Capacity::formatByteSize(d.physicalSectorSize()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Cylinder size:"), i18ncp("@label", "1 Sector", "%1 Sectors", d.cylinderSize()), cols(area), x, y);
-    createLabels(i18nc("@label device", "Primaries/Max:"), maxPrimaries, cols(area), x, y);
+    if (d.type() == Device::Disk_Device) {
+        const DiskDevice& disk = dynamic_cast<const DiskDevice&>(d);
+
+        createLabels(i18nc("@label device", "Type:"), type, cols(area), x, y);
+        createLabels(i18nc("@label device", "Capacity:"), Capacity::formatByteSize(disk.capacity()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Total sectors:"), QLocale().toString(disk.totalSectors()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Heads:"), QString::number(disk.heads()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Cylinders:"), QLocale().toString(disk.cylinders()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Sectors:"), QLocale().toString(disk.sectorsPerTrack()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Logical sector size:"), Capacity::formatByteSize(disk.logicalSectorSize()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Physical sector size:"), Capacity::formatByteSize(disk.physicalSectorSize()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Cylinder size:"), i18ncp("@label", "1 Sector", "%1 Sectors", disk.cylinderSize()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Primaries/Max:"), maxPrimaries, cols(area), x, y);
+    } else if (d.type() == Device::LVM_Device) {
+        const LvmDevice& lvm = dynamic_cast<const LvmDevice&>(d);
+        createLabels(i18nc("@label device", "Volume Type:"), QStringLiteral("LVM"), cols(area), x, y);
+        createLabels(i18nc("@label device", "Capacity:"), Capacity::formatByteSize(lvm.capacity()), cols(area), x, y);
+        createLabels(i18nc("@label device", "PE Size:"), Capacity::formatByteSize(lvm.peSize()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Total PE:"),QString::number(lvm.totalPE()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Allocated PE:"), QString::number(lvm.allocatedPE()), cols(area), x, y);
+        createLabels(i18nc("@label device", "Free PE:"), QString::number(lvm.freePE()), cols(area), x, y);
+    }
 }
 
 quint32 InfoPane::cols(Qt::DockWidgetArea area) const
