@@ -240,6 +240,10 @@ protected:
 
     void onRefreshDevices();
     void onCreateNewPartitionTable();
+    void onCreateNewVolumeGroup();
+    void onRemoveVolumeGroup();
+    void onResizeVolumeGroup();
+    void onDeactivateVolumeGroup();
     void onExportPartitionTable();
     void onImportPartitionTable();
 
@@ -251,6 +255,7 @@ protected:
     void onSettingsChanged();
 
     void onFileSystemSupport();
+    void onShowAboutKPMcore();
 
     void onSmartStatusDevice();
     void onPropertiesDevice(const QString& deviceNode = {});
