@@ -23,6 +23,7 @@
 
 #include <core/partition.h>
 #include <core/device.h>
+#include <core/lvmdevice.h>
 
 #include <fs/filesystemfactory.h>
 #include <fs/luks.h>
@@ -47,14 +48,18 @@
 */
 NewDialog::NewDialog(QWidget* parent, Device& device, Partition& unallocatedPartition, PartitionRole::Roles r) :
     SizeDialogBase(parent, device, unallocatedPartition, unallocatedPartition.firstSector(), unallocatedPartition.lastSector()),
-    m_PartitionRoles(r)
+    m_PartitionRoles(r),
+    m_IsValidPassword(true),
+    m_IsValidLVName(true)
 {
-    setWindowTitle(i18nc("@title:window", "Create a new partition"));
+    setWindowTitle(xi18nc("@title:window", "Create a new partition"));
 
     setupDialog();
     setupConstraints();
     setupConnections();
 
+    updateOkButtonStatus();
+
     KConfigGroup kcg(KSharedConfig::openConfig(), "newDialog");
     restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
 }
@@ -68,15 +73,16 @@ NewDialog::~NewDialog()
 void NewDialog::setupDialog()
 {
     QStringList fsNames;
-    foreach (const FileSystem * fs, FileSystemFactory::map())
+    for (const auto &fs : FileSystemFactory::map()) {
         if (fs->supportCreate() != FileSystem::cmdSupportNone &&
             fs->type() != FileSystem::Extended &&
             fs->type() != FileSystem::Luks)
             fsNames.append(fs->name());
+    }
 
     qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-    foreach (const QString & fsName, fsNames)
+    foreach (const auto &fsName, fsNames)
         dialogWidget().comboFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
 
     QString selected = FileSystem::nameForType(GuiHelpers::defaultFileSystem());
@@ -97,6 +103,20 @@ void NewDialog::setupDialog()
     dialogWidget().checkBoxEncrypt().hide();
     dialogWidget().editPassphrase().hide();
 
+    if (device().type() == Device::Disk_Device) {
+        dialogWidget().lvName().hide();
+        dialogWidget().textLVName().hide();
+    }
+
+    if (device().type() == Device::LVM_Device) {
+        dialogWidget().hideBeforeAndAfter();
+        detailsWidget().checkAlign().setChecked(false);
+        detailsWidget().checkAlign().setEnabled(false);
+        detailsButton->hide();
+        dialogWidget().comboFileSystem().removeItem(dialogWidget().comboFileSystem().findText(QStringLiteral("lvm2 pv")));
+        m_IsValidLVName = false;
+    }
+
     dialogWidget().editPassphrase().setMinimumPasswordLength(1);
     dialogWidget().editPassphrase().setMaximumPasswordLength(512); // cryptsetup does not support longer passwords
 
@@ -104,8 +124,6 @@ void NewDialog::setupDialog()
     KColorScheme colorScheme(QPalette::Active, KColorScheme::View);
     dialogWidget().editPassphrase().setBackgroundWarningColor(colorScheme.background(KColorScheme::NegativeBackground).color());
 
-    // listen to password status updates
-    connect(&dialogWidget().editPassphrase(), &KNewPasswordWidget::passwordStatusChanged, this, &NewDialog::slotPasswordStatusChanged);
 
     // don't move these above the call to parent's setupDialog, because only after that has
     // run there is a valid partition set in the part resizer widget and they will need that.
@@ -121,10 +139,18 @@ void NewDialog::setupConnections()
     connect(&dialogWidget().checkBoxEncrypt(), &QCheckBox::toggled, this, &NewDialog::onRoleChanged);
     connect(&dialogWidget().comboFileSystem(), static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewDialog::onFilesystemChanged);
     connect(&dialogWidget().label(), &QLineEdit::textChanged, this, &NewDialog::onLabelChanged);
+    // listen to password status updates
+    connect(&dialogWidget().editPassphrase(), &KNewPasswordWidget::passwordStatusChanged, this, &NewDialog::slotPasswordStatusChanged);
+    connect(&dialogWidget().lvName(), &QLineEdit::textChanged, this, &NewDialog::onLVNameChanged);
 
     SizeDialogBase::setupConnections();
 }
 
+bool NewDialog::canMove() const
+{
+    return (device().type() == Device::LVM_Device) ? false : true;
+}
+
 void NewDialog::accept()
 {
     if (partition().roles().has(PartitionRole::Extended)) {
@@ -197,6 +223,7 @@ void NewDialog::onFilesystemChanged(int idx)
     updateFileSystem(FileSystem::typeForName(dialogWidget().comboFileSystem().itemText(idx)));
 
     setupConstraints();
+    updateOkButtonStatus();
 
     const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText()), -1, -1, -1, QString());
     dialogWidget().m_EditLabel->setMaxLength(fs->maxLabelLength());
@@ -219,12 +246,27 @@ void NewDialog::slotPasswordStatusChanged()
     switch (dialogWidget().editPassphrase().passwordStatus()) {
     case KNewPasswordWidget::WeakPassword:
     case KNewPasswordWidget::StrongPassword:
-        okButton->setEnabled(true);
+        m_IsValidPassword = true;
         break;
     default:
-        okButton->setEnabled(false);
+        m_IsValidPassword = false;
         break;
     }
+    updateOkButtonStatus();
+}
+
+void NewDialog::onLVNameChanged(const QString& newName)
+{
+    partition().setPartitionPath(device().deviceNode() + QStringLiteral("/") + newName.trimmed());
+    if ((dialogWidget().lvName().isVisible() &&
+        dialogWidget().lvName().text().isEmpty()) ||
+        (device().type() == Device::LVM_Device &&
+         dynamic_cast<LvmDevice&>(device()).partitionNodes().contains(partition().partitionPath())) ) {
+        m_IsValidLVName = false;
+    } else {
+        m_IsValidLVName = true;
+    }
+    updateOkButtonStatus();
 }
 
 void NewDialog::updateHideAndShow()
@@ -262,3 +304,8 @@ void NewDialog::updateHideAndShow()
     }
 
 }
+
+void NewDialog::updateOkButtonStatus()
+{
+    okButton->setEnabled(isValidPassword() && isValidLVName());
+}
