@@ -24,7 +24,6 @@
 
 #include <gui/partwidget.h>
 
-#include <QApplication>
 #include <QMouseEvent>
 
 #include <KLocalizedString>
@@ -35,7 +34,7 @@
 PartTableWidget::PartTableWidget(QWidget* parent) :
     PartWidgetBase(parent),
     m_PartitionTable(nullptr),
-    m_LabelEmpty(i18nc("@info", "Please select a device."), this),
+    m_LabelEmpty(xi18nc("@info", "Please select a device."), this),
     m_ReadOnly(false)
 {
     labelEmpty().setAlignment(Qt::AlignVCenter | Qt::AlignHCenter);
@@ -51,7 +50,7 @@ void PartTableWidget::setPartitionTable(const PartitionTable* ptable)
     m_PartitionTable = ptable;
 
     if (partitionTable() != nullptr) {
-        foreach(const Partition * p, partitionTable()->children()) {
+        for (const auto &p : partitionTable()->children()) {
             PartWidget* w = new PartWidget(this, p);
             w->setVisible(true);
             w->setFileSystemColorCode(GuiHelpers::fileSystemColorCodesFromSettings());
@@ -60,7 +59,7 @@ void PartTableWidget::setPartitionTable(const PartitionTable* ptable)
 
     if (childWidgets().isEmpty()) {
         labelEmpty().setVisible(true);
-        labelEmpty().setText(i18nc("@info", "No valid partition table was found on this device."));
+        labelEmpty().setText(xi18nc("@info", "No valid partition table was found on this device."));
         labelEmpty().resize(size());
     } else {
         labelEmpty().setVisible(false);
@@ -72,18 +71,20 @@ void PartTableWidget::setPartitionTable(const PartitionTable* ptable)
 
 PartWidget* PartTableWidget::activeWidget()
 {
-    foreach(PartWidget * pw, findChildren<PartWidget*>())
-    if (pw->isActive())
-        return pw;
+    const auto children = findChildren<PartWidget*>();
+    for (auto &pw : children)
+        if (pw->isActive())
+            return pw;
 
     return nullptr;
 }
 
 const PartWidget* PartTableWidget::activeWidget() const
 {
-    foreach(const PartWidget * pw, findChildren<PartWidget*>())
-    if (pw->isActive())
-        return pw;
+    const auto children = findChildren<PartWidget*>();
+    for (const auto &pw : children)
+        if (pw->isActive())
+            return pw;
 
     return nullptr;
 }
@@ -115,10 +116,12 @@ void PartTableWidget::setActivePartition(const Partition* p)
     if (isReadOnly())
         return;
 
-    foreach(PartWidget * pw, findChildren<PartWidget*>())
-    if (pw->partition() == p) {
-        setActiveWidget(pw);
-        return;
+    const auto children = findChildren<PartWidget*>();
+    for (auto &pw : children) {
+        if (pw->partition() == p) {
+            setActiveWidget(pw);
+            return;
+        }
     }
 
     setActiveWidget(nullptr);
@@ -135,7 +138,7 @@ void PartTableWidget::clear()
     // that its event handler is currently running. therefore, do not delete
     // the part widgets here but schedule them for deletion once the app
     // returns to the main loop (and the event handler has finished).
-    foreach(PartWidget * p, childWidgets()) {
+    for (auto &p : childWidgets()) {
         p->setVisible(false);
         p->deleteLater();
         p->setParent(nullptr);
