@@ -34,8 +34,10 @@
 
 #include <KLocalizedString>
 
+#include <QFrame>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 #include <config.h>
 
@@ -62,11 +64,11 @@ SizeDialogBase::SizeDialogBase(QWidget* parent, Device& d, Partition& part, qint
     detailsLayout->addWidget(&detailsWidget());
     detailsWidget().hide();
 
-    QDialogButtonBox* dialogButtonBox = new QDialogButtonBox;
-    detailsButton = new QPushButton;
+    QDialogButtonBox* dialogButtonBox = new QDialogButtonBox(this);
+    detailsButton = new QPushButton(dialogButtonBox);
     okButton = dialogButtonBox->addButton(QDialogButtonBox::Ok);
     cancelButton = dialogButtonBox->addButton(QDialogButtonBox::Cancel);
-    detailsButton->setText(i18nc("@item:button advanced settings button", "Advanced") + QStringLiteral(" >>"));
+    detailsButton->setText(xi18nc("@action:button advanced settings button", "Advanced") + QStringLiteral(" >>"));
     dialogButtonBox->addButton(detailsButton, QDialogButtonBox::ActionRole);
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
     mainLayout->addWidget(dialogButtonBox);
@@ -115,8 +117,8 @@ void SizeDialogBase::setupConstraints()
     dialogWidget().partResizerWidget().setMinimumLength(minimumLength());
     dialogWidget().partResizerWidget().setMaximumLength(maximumLength());
 
-    dialogWidget().labelMinSize().setText(Capacity::formatByteSize(minimumLength() * device().logicalSectorSize()));
-    dialogWidget().labelMaxSize().setText(Capacity::formatByteSize(maximumLength() * device().logicalSectorSize()));
+    dialogWidget().labelMinSize().setText(Capacity::formatByteSize(minimumLength() * device().logicalSize()));
+    dialogWidget().labelMaxSize().setText(Capacity::formatByteSize(maximumLength() * device().logicalSize()));
 
     dialogWidget().spinCapacity().setEnabled(canShrink() || canGrow());
 
@@ -159,7 +161,7 @@ void SizeDialogBase::toggleDetails()
 {
     const bool isVisible = detailsWidget().isVisible();
     detailsWidget().setVisible(!isVisible);
-    detailsButton->setText(i18n("&Advanced") + (isVisible ? QStringLiteral(" >>") : QStringLiteral(" <<")));
+    detailsButton->setText(xi18nc("@action:button", "&Advanced") + (isVisible ? QStringLiteral(" >>") : QStringLiteral(" <<")));
 }
 
 void SizeDialogBase::onSpinFreeBeforeChanged(double newBefore)
@@ -337,9 +339,9 @@ void SizeDialogBase::onAlignToggled(bool align)
     dialogWidget().spinCapacity().setSingleStep(capacityStep);
 
     // if align is on, turn off keyboard tracking for all spin boxes to avoid the two clashing
-    foreach(QAbstractSpinBox * box, dialogWidget().findChildren<QAbstractSpinBox*>() +
-            detailsWidget().findChildren<QAbstractSpinBox*>())
-    box->setKeyboardTracking(!align);
+    const auto children = dialogWidget().findChildren<QAbstractSpinBox*>() + detailsWidget().findChildren<QAbstractSpinBox*>();
+    for (const auto &box : children)
+        box->setKeyboardTracking(!align);
 
     if (align) {
         onSpinFirstSectorChanged(partition().firstSector());
@@ -415,11 +417,11 @@ qint64 SizeDialogBase::maximumLength() const
 
 static double sectorsToDialogUnit(const Device& d, qint64 v)
 {
-    return Capacity(v * d.logicalSectorSize()).toDouble(preferredUnit());
+    return Capacity(v * d.logicalSize()).toDouble(preferredUnit());
 }
 
 static qint64 dialogUnitToSectors(const Device& d, double v)
 {
-    return v * Capacity::unitFactor(Capacity::Byte, preferredUnit()) / d.logicalSectorSize();
+    return v * Capacity::unitFactor(Capacity::Byte, preferredUnit()) / d.logicalSize();
 }
 
