@@ -40,10 +40,18 @@ public:
         return *m_PartResizerWidget;
     }
 
+    QLabel& labelFreeBefore() {
+        Q_ASSERT(m_LabelFreeBefore);
+        return *m_LabelFreeBefore;
+    }
     QDoubleSpinBox& spinFreeBefore() {
         Q_ASSERT(m_SpinFreeBefore);
         return *m_SpinFreeBefore;
     }
+    QLabel& labelFreeAfter() {
+        Q_ASSERT(m_LabelFreeAfter);
+        return *m_LabelFreeAfter;
+    }
     QDoubleSpinBox& spinFreeAfter() {
         Q_ASSERT(m_SpinFreeAfter);
         return *m_SpinFreeAfter;
@@ -89,6 +97,14 @@ public:
         Q_ASSERT(m_EditPassphrase);
         return *m_EditPassphrase;
     }
+    QLabel& textLVName() {
+        Q_ASSERT(m_LabelTextLVName);
+        return *m_LabelTextLVName;
+    }
+    QLineEdit& lvName() {
+        Q_ASSERT(m_EditLVName);
+        return *m_EditLVName;
+    }
 
     QLabel& textLabel() {
         Q_ASSERT(m_LabelTextLabel);
@@ -135,6 +151,12 @@ public:
         delete m_LabelTextNoSetLabel;
         m_LabelTextNoSetLabel = nullptr;
     }
+    void hideBeforeAndAfter() {
+        labelFreeBefore().hide();
+        spinFreeBefore().hide();
+        labelFreeAfter().hide();
+        spinFreeAfter().hide();
+    }
 };
 
 #endif
